import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixBottomMenuUHFPage extends StatefulWidget {
  const PhoenixBottomMenuUHFPage({Key? key}) : super(key: key);

  @override
  State<PhoenixBottomMenuUHFPage> createState() => _PhoenixBottomMenuUHFPage();
}

class _PhoenixBottomMenuUHFPage extends State<PhoenixBottomMenuUHFPage> {
  PageController? _tabController;
  int selectedIndex = 0;

  @override
  void initState() {
    super.initState();
    _tabController = PageController();
  }

  Widget generateIcon(String icon) {
    return SvgPicture.asset(icon, width: 25, height: 25);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        title: const Text('Phoenix Bottom Navigation UHF Sample App'),
      ),
      bottomNavigationBar: PhoenixBottomMenuUHF(
        selectedIndex: selectedIndex,
        navBarItems: [
          NavBarItem(
            name: "Home",
            image: generateIcon('assets/tab/home_default.svg'),
            selectedImage: generateIcon('assets/tab/home_selected.svg'),
          ),
          NavBarItem(
            name: "Feed",
            image: generateIcon('assets/tab/feed_default.svg'),
            selectedImage: generateIcon('assets/tab/feed_selected.svg'),
          ),
          NavBarItem(
            name: "Community",
            image: generateIcon('assets/tab/community_default.svg'),
            selectedImage: generateIcon('assets/tab/community_selected.svg'),
          ),
          NavBarItem(
            name: "Account",
            image: generateIcon('assets/tab/account_default.svg'),
            selectedImage: generateIcon('assets/tab/account_selected.svg'),
          ),
        ],
        selectedTabColor: Colors.red,
        unselectedTabColor: Colors.black54,
        // bottomNavBarType: BottomNavigationBarType.shifting,
        onTabChange: (index) {
          setState(() {
            selectedIndex = index;
            _tabController!.jumpToPage(index);
          });
        },
      ),
      body: PageView(
        physics: const NeverScrollableScrollPhysics(),
        children: [
          centerButton("Go To Tab Feed", 1),
          centerButton("Go To Tab Comunity", 2),
          centerButton("Go To Tab Account", 3),
          centerButton("Go To Tab Home", 0),
        ],
        controller: _tabController,
      ),
    );
  }

  centerButton(String text, int page) {
    return Center(
      child: PhoenixButton(
        content: Text(
          text,
        ),
        margin: const EdgeInsets.only(
          left: 16,
          top: 16,
          right: 16,
        ),
        buttonElevation: 2,
        onPressed: () {
          setState(() {
            selectedIndex = page;
            _tabController!.jumpToPage(page);
          });
        },
        radius: 10,
      ),
    );
  }
}
