import 'package:flutter/material.dart';

class PhoenixCard extends StatelessWidget {
  const PhoenixCard({
    Key? key,
    this.width,
    this.padding,
    this.margin,
    this.onTap,
    this.backgroundColor,
    this.image,
    required this.title,
    required this.description,
    this.footer,
    this.footerSeparatorVisible = false,
    this.imageHeight = 150.0,
    this.footerSeparator,
    this.label,
  }) : super(key: key);

  /// Decoration parameter
  final double? width;
  final EdgeInsets? padding;
  final EdgeInsets? margin;
  final VoidCallback? onTap;
  final Color? backgroundColor;
  final double borderRadius = 4;

  /// Widget inside card
  final Widget? image;
  final Widget title;
  final Widget description;
  final Widget? footer;
  final bool footerSeparatorVisible;
  final Widget? footerSeparator;
  final Widget? label;

  final double? imageHeight;

  @override
  Widget build(BuildContext context) {
    return Container(
      ///use maxFinite if width is null
      width: width ?? double.maxFinite,
      padding: padding,
      margin: margin ??
          const EdgeInsets.symmetric(
            horizontal: 16,
            vertical: 8,
          ),
      decoration: BoxDecoration(
        color: backgroundColor ?? Colors.white,
        borderRadius: BorderRadius.all(Radius.circular(borderRadius)),
        boxShadow: [
          BoxShadow(
            offset: const Offset(0, 1),
            color: Colors.black.withOpacity(0.16),
            blurRadius: 4,
          ),
        ],
      ),
      child: ClipRRect(
        borderRadius: BorderRadius.circular(borderRadius),
        child: Material(
          color: Colors.transparent,
          child: InkWell(
            borderRadius: BorderRadius.all(Radius.circular(borderRadius)),
            onTap: onTap,
            child: Column(
              mainAxisSize: MainAxisSize.min,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                /// Only visible if Image Available
                if (image != null)
                  SizedBox(
                    width: double.maxFinite,
                    height: imageHeight,
                    child: Stack(
                      children: [
                        image!,
                        if (label != null) label!,
                      ],
                    ),
                  ),
                Padding(
                  padding: const EdgeInsets.all(16),
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [title, const SizedBox(height: 4), description],
                  ),
                ),

                /// Only visible if Footer Available
                if (footer != null && footerSeparatorVisible)
                  const Divider(height: 16),
                if (footer != null && footerSeparator != null) footerSeparator!,
                if (footer != null)
                  Padding(
                    padding: const EdgeInsets.only(
                      left: 16,
                      right: 16,
                      bottom: 16,
                    ),
                    child: footer,
                  )
              ],
            ),
          ),
        ),
      ),
    );
  }
}
