import 'dart:async';

import 'package:flutter/material.dart';

class PhoenixSearchbar extends StatefulWidget {
  const PhoenixSearchbar({
    Key? key,
    this.hintText = "",
    this.onChanged,
    this.fillColor = const Color(0xFFF9F9F9),
    this.enabled = true,
    this.fontSize = 14,
    required this.cancelText,
    required this.onCancel,
    this.isFocus = true,
  }) : super(key: key);

  final String hintText;
  final Function(String)? onChanged;
  final Color fillColor;
  final bool enabled;
  final double fontSize;
  final String cancelText;
  final VoidCallback onCancel;
  final bool isFocus;

  @override
  State<PhoenixSearchbar> createState() => _PhoenixSearchbarState();
}

class _PhoenixSearchbarState extends State<PhoenixSearchbar> {
  final _debouncer = Debouncer();
  final _controller = TextEditingController();
  final _fnSearch = FocusNode();

  @override
  void initState() {
    super.initState();
    if (widget.isFocus) {
      _fnSearch.requestFocus();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: [
        Expanded(
          child: SizedBox(
            height: 34,
            child: TextField(
              onChanged: (value) async {
                _debouncer.run(() {
                  widget.onChanged?.call(value);
                });
              },
              controller: _controller,
              focusNode: _fnSearch,
              enabled: widget.enabled,
              decoration: InputDecoration(
                enabled: widget.enabled,
                contentPadding: EdgeInsets.zero,
                fillColor: widget.fillColor,
                filled: true,
                isDense: true,
                hintText: widget.hintText,
                hintStyle: TextStyle(
                  color: const Color(0xff75767A),
                  fontSize: widget.fontSize,
                ),
                prefixIcon: const Padding(
                  padding: EdgeInsets.zero,
                  child: Icon(
                    Icons.search,
                    size: 24,
                    color: Color(0xff75767A),
                  ),
                ),
                focusedBorder: const OutlineInputBorder(
                  borderRadius: BorderRadius.all(Radius.circular(24)),
                  borderSide: BorderSide(width: 0, color: Color(0xFFF9F9F9)),
                ),
                disabledBorder: const OutlineInputBorder(
                  borderRadius: BorderRadius.all(Radius.circular(24)),
                  borderSide: BorderSide(width: 0, color: Color(0xFFF9F9F9)),
                ),
                enabledBorder: const OutlineInputBorder(
                  borderRadius: BorderRadius.all(Radius.circular(24)),
                  borderSide: BorderSide(width: 0, color: Color(0xFFF9F9F9)),
                ),
                border: const OutlineInputBorder(
                  borderRadius: BorderRadius.all(Radius.circular(24)),
                  borderSide: BorderSide(width: 0, color: Color(0xFFF9F9F9)),
                ),
              ),
            ),
          ),
        ),
        TextButton(
          style: TextButton.styleFrom(
            padding: const EdgeInsets.only(left: 16),
          ),
          onPressed: widget.onCancel,
          child: Text(
            widget.cancelText,
            style: const TextStyle(
              color: Color(0xFF67C1BF),
              fontSize: 16,
              fontWeight: FontWeight.w500,
            ),
          ),
        )
      ],
    );
  }
}

/// Use debouncer to detect user not in typing
class Debouncer {
  Duration? duration;
  VoidCallback? action;
  Timer? _timer;

  Debouncer({this.duration});

  run(VoidCallback action) {
    if (_timer != null) {
      _timer!.cancel();
    }
    _timer = Timer(duration ?? const Duration(milliseconds: 300), action);
  }
}
